@@ -432,7 +432,7 @@ static size_t EncodeImage(Image *image,const size_t bytes_per_line,
           break;
       *q++=(unsigned char) i;
       *q++=(*p);
-      p+=i;
+      p+=(ptrdiff_t) i;
     }
     /*
       End of line.
@@ -843,6 +843,11 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
             bmp_info.blue_mask=ReadBlobLSBLong(image);
             if (bmp_info.compression == BI_ALPHABITFIELDS)
               bmp_info.alpha_mask=ReadBlobLSBLong(image);
+            if (((bmp_info.size == 40) ||
+                 (bmp_info.compression == BI_ALPHABITFIELDS)) &&
+                 (bmp_info.bits_per_pixel != 16) &&
+                 (bmp_info.bits_per_pixel != 32))
+              ThrowReaderException(CorruptImageError,"UnsupportedBitsPerPixel");
           }
         if (bmp_info.size > 40)
           {
@@ -1179,7 +1184,7 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     y=-1;
                     break;
                   }
-                p+=4;
+                p+=(ptrdiff_t) 4;
               }
             }
           }
@@ -1426,19 +1431,19 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
             pixel|=(*p++) << 8;
             red=((pixel & bmp_info.red_mask) << shift.red) >> 16;
             if (quantum_bits.red == 5)
-              red|=((red & 0xe000) >> 5);
+              red|=((red & 0xff000) >> 5);
             if (quantum_bits.red <= 8)
               red|=((red & 0xff00) >> 8);
             green=((pixel & bmp_info.green_mask) << shift.green) >> 16;
             if (quantum_bits.green == 5)
-              green|=((green & 0xe000) >> 5);
+              green|=((green & 0xff000) >> 5);
             if (quantum_bits.green == 6)
-              green|=((green & 0xc000) >> 6);
+              green|=((green & 0xff00) >> 6);
             if (quantum_bits.green <= 8)
               green|=((green & 0xff00) >> 8);
             blue=((pixel & bmp_info.blue_mask) << shift.blue) >> 16;
             if (quantum_bits.blue == 5)
-              blue|=((blue & 0xe000) >> 5);
+              blue|=((blue & 0xff000) >> 5);
             if (quantum_bits.blue <= 8)
               blue|=((blue & 0xff00) >> 8);
             SetPixelRed(q,ScaleShortToQuantum((unsigned short) red));
@@ -2264,7 +2269,7 @@ static MagickBooleanType WriteBMPImage(const ImageInfo *image_info,Image *image)
                   GetPixelBlue(p),31));
               }
             *((unsigned short *) q)=pixel;
-            q+=2;
+            q+=(ptrdiff_t) 2;
             p++;
           }
           for (x=2L*(ssize_t) image->columns; x < (ssize_t) bytes_per_line; x++)
