@@ -1851,7 +1851,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                 q=pixels;
               }
             (void) memcpy((char *) q,buffer,extent);
-            q+=extent;
+            q+=(ptrdiff_t) extent;
             p++;
           }
           *q++='\n';
@@ -1927,7 +1927,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                 q=pixels;
               }
             (void) memcpy((char *) q,buffer,extent);
-            q+=extent;
+            q+=(ptrdiff_t) extent;
             p++;
           }
           *q++='\n';
