@@ -995,7 +995,7 @@ static MagickBooleanType LoadMagicCache(LinkedListInfo *cache,const char *xml,
                         *end;
 
                       *q++=(unsigned char) strtol(p,&end,8);
-                      p+=(end-p);
+                      p+=(ptrdiff_t) (end-p);
                       magic_info->length++;
                       continue;
                     }
